@@ -1,5 +1,5 @@
 """
-$Id: Base.py,v 1.12.2.11.2.5 2012/04/28 19:24:30 customdesigned Exp $
+$Id$
 
 This file is part of the pydns project.
 Homepage: http://pydns.sourceforge.net
@@ -282,6 +282,11 @@ class DnsRequest:
                 # servers worked:
                 first_socket_error = first_socket_error or e
                 continue
+            except TimeoutError as t:
+                first_socket_error = first_socket_error or t
+                continue
+            if self.response:
+                break
         if not self.response and first_socket_error:
             raise first_socket_error
 
@@ -319,6 +324,11 @@ class DnsRequest:
             except socket.error as e:
                 first_socket_error = first_socket_error or e
                 continue
+            except TimeoutError as t:
+                first_socket_error = first_socket_error or t
+                continue
+            if self.response:
+                break
         if not self.response and first_socket_error:
             raise first_socket_error
 
@@ -383,10 +393,7 @@ def ParseOSXSysConfig():
         defaults['server'].extend(currentset)
 
 #
-# $Log: Base.py,v $
-# Revision 1.12.2.11.2.5  2012/04/28 19:24:30  customdesigned
-# Scott's 3.0.2 changes
-#
+# $Log$
 # Revision 1.12.2.11.2.4  2011/08/04 22:53:09  customdesigned
 # Add OSX support
 #
