@@ -1,5 +1,5 @@
 """
-$Id: Class.py,v 1.6.4.2 2011/03/23 01:42:07 customdesigned Exp $
+$Id$
 
  This file is part of the pydns project.
  Homepage: http://pydns.sourceforge.net
@@ -34,10 +34,7 @@ def classstr(klass):
     else: return repr(klass)
 
 #
-# $Log: Class.py,v $
-# Revision 1.6.4.2  2011/03/23 01:42:07  customdesigned
-# Changes from 2.3 branch
-#
+# $Log$
 # Revision 1.6.4.1  2011/02/18 19:35:22  customdesigned
 # Python3 updates from Scott Kitterman
 #
