@@ -1,6 +1,6 @@
 # -*- encoding: utf-8 -*-
 """
- $Id: Lib.py,v 1.11.2.7.2.3 2012/04/28 19:24:30 customdesigned Exp $
+ $Id$
 
  This file is part of the pydns project.
  Homepage: http://pydns.sourceforge.net
@@ -494,12 +494,6 @@ class RRunpacker(Unpacker):
         else:
             enc = DNS.LABEL_ENCODING
         return self.getaddr().decode(enc)
-    def getAAAAdata(self):
-        if DNS.LABEL_UTF8:
-            enc = 'utf8'
-        else:
-            enc = DNS.LABEL_ENCODING
-        return self.getaddr6().decode(enc)
     def getWKSdata(self):
         address = self.getaddr()
         protocol = ord(self.getbyte())
@@ -723,10 +717,7 @@ def dumpRR(u):
 if __name__ == "__main__":
     testpacker()
 #
-# $Log: Lib.py,v $
-# Revision 1.11.2.7.2.3  2012/04/28 19:24:30  customdesigned
-# Scott's 3.0.2 changes
-#
+# $Log$
 # Revision 1.11.2.7.2.2  2011/03/23 01:42:07  customdesigned
 # Changes from 2.3 branch
 #
