@@ -1,5 +1,5 @@
 """
- $Id: Status.py,v 1.7.4.2 2011/03/23 01:42:07 customdesigned Exp $
+ $Id$
 
  This file is part of the pydns project.
  Homepage: http://pydns.sourceforge.net
@@ -40,10 +40,7 @@ def statusstr(status):
     else: return repr(status)
 
 #
-# $Log: Status.py,v $
-# Revision 1.7.4.2  2011/03/23 01:42:07  customdesigned
-# Changes from 2.3 branch
-#
+# $Log$
 # Revision 1.7.4.1  2011/02/18 19:35:22  customdesigned
 # Python3 updates from Scott Kitterman
 #
