@@ -1,6 +1,6 @@
 # -*- encoding: utf-8 -*-
 """
- $Id: Type.py,v 1.6.2.2.2.2 2011/03/23 01:42:07 customdesigned Exp $
+ $Id$
 
  This file is part of the pydns project.
  Homepage: http://pydns.sourceforge.net
@@ -53,10 +53,7 @@ def typestr(type):
     if type in typemap: return typemap[type]
     else: return repr(type)
 #
-# $Log: Type.py,v $
-# Revision 1.6.2.2.2.2  2011/03/23 01:42:07  customdesigned
-# Changes from 2.3 branch
-#
+# $Log$
 # Revision 1.6.2.2.2.1  2011/02/18 19:35:22  customdesigned
 # Python3 updates from Scott Kitterman
 #
