@@ -1,5 +1,5 @@
 """
- $Id: win32dns.py,v 1.3.2.1.2.1 2011/02/18 19:35:22 customdesigned Exp $
+ $Id$
 
  Extract a list of TCP/IP name servers from the registry 0.1
     0.1 Strobl 2001-07-19
@@ -115,10 +115,7 @@ if __name__=="__main__":
     print("Name servers:",RegistryResolve())
 
 #
-# $Log: win32dns.py,v $
-# Revision 1.3.2.1.2.1  2011/02/18 19:35:22  customdesigned
-# Python3 updates from Scott Kitterman
-#
+# $Log$
 # Revision 1.3.2.1  2007/05/22 20:26:49  customdesigned
 # Fix win32 nameserver discovery.
 #
